@@ -16,13 +16,11 @@ fn main() {
 
     cfg.compile("pbx");
 
-    #[cfg(target = "cdylib")]
     build_def();
 }
 
 //生成导出符号定义文件
 //解决rust msvc 32bit dll编译符号被截断的问题
-#[cfg(target = "cdylib")]
 fn build_def() {
     use std::{fs::OpenOptions, io::Write, path::PathBuf};
 
@@ -50,7 +48,9 @@ fn build_def() {
     //覆盖DEF文件链接
     println!("cargo:rustc-cdylib-link-arg=/DEF:{}", file_path.display());
     //生成map文件
+    #[cfg(feature = "symbol_map")]
     println!("cargo:rustc-cdylib-link-arg=/MAP:symbol.map");
     //map文件生成导出符号表
+    #[cfg(feature = "symbol_map")]
     println!("cargo:rustc-cdylib-link-arg=/MAPINFO:EXPORTS");
 }
